@@ -192,11 +192,16 @@ jomo2com.MCMCchain <-
     meanobs<-colMeans(Yi,na.rm=TRUE)
     if (!is.null(start.imp)) {
       start.imp<-as.matrix(start.imp)
-      if ((nrow(start.imp)!=nrow(Yimp2))||(ncol(Yimp2)!=ncol(start.imp))) {
+      if ((nrow(start.imp)!=nrow(Yimp2))||(ncol(Yimp2)>ncol(start.imp))) {
         cat("start.imp dimensions incorrect. Not using start.imp as starting value for the imputed dataset.\n")
         start.imp=NULL
       } else {
-        Yimp2<-start.imp
+        if ((nrow(start.imp)==nrow(Yimp2))&(ncol(Yimp2)<ncol(start.imp))) {
+          Yimp2<-start.imp[,1:ncol(Yimp2)]
+          cat("NOTE: start.imp has more columns than needed. Dropping unnecessary columns.\n")
+        } else {
+          Yimp2<-start.imp
+        }
       }
     }
     if (is.null(start.imp)) {
@@ -205,11 +210,16 @@ jomo2com.MCMCchain <-
     l2.meanobs<-colMeans(Y2i,na.rm=TRUE)
     if (!is.null(l2.start.imp)) {
       l2.start.imp<-as.matrix(l2.start.imp)
-      if ((nrow(l2.start.imp)!=nrow(Y2imp2))||(ncol(Y2imp2)!=ncol(l2.start.imp))) {
+      if ((nrow(l2.start.imp)!=nrow(Y2imp2))||(ncol(Y2imp2)>ncol(l2.start.imp))) {
         cat("l2.start.imp dimensions incorrect. Not using l2.start.imp as starting value for the level 2 imputed dataset.\n")
         l2.start.imp=NULL
       } else {
-        Y2imp2<-l2.start.imp
+        if ((nrow(l2.start.imp)==nrow(Y2imp2))&(ncol(Y2imp2)<ncol(l2.start.imp))) {
+          Y2imp2<-l2.start.imp[,1:ncol(Y2imp2)]
+          cat("NOTE: l2.start.imp has more columns than needed. Dropping unnecessary columns.\n")
+        } else {
+          Y2imp2<-l2.start.imp
+        }
       }
     }
     if (is.null(l2.start.imp)) {
